body {
    font-family: 'PT Sans', sans-serif;
    background: rgb(215, 215, 215);
    background: -webkit-gradient(radial, 50% 50%, 0, 50% 50%, 500, from(rgb(240, 240, 240)), to(rgb(190, 190, 190)));
    background: -webkit-radial-gradient(rgb(240, 240, 240), rgb(190, 190, 190));
    background:    -moz-radial-gradient(rgb(240, 240, 240), rgb(190, 190, 190));
    background:     -ms-radial-gradient(rgb(240, 240, 240), rgb(190, 190, 190));
    background:      -o-radial-gradient(rgb(240, 240, 240), rgb(190, 190, 190));
    background:         radial-gradient(rgb(240, 240, 240), rgb(190, 190, 190));
}
h1, h2, h3, h4, h5, h6 {
    margin: 0;
    padding: 0;
    border: 0;
    font-size: 100%;
    font: inherit;
}
h1 { font-size: 220%; }
h2 { font-size: 200%; }
h3 { font-size: 180%; }
h4 { font-size: 160%; }
h5 { font-size: 140%; }
h6 { font-size: 120%; }
b, strong { font-weight: bold }
i, em { font-style: italic }
a {
    color: inherit;
    text-decoration: none;
    padding: 0 0.1em;
    -webkit-transition: 0.5s;
    -moz-transition:    0.5s;
    -ms-transition:     0.5s;
    -o-transition:      0.5s;
    transition:         0.5s;
}
a:hover,
a:focus {
    background: rgba(255,255,255,1);
    text-shadow: -1px -1px 2px rgba(100,100,100,0.5);
}
pre code{
    display: block;
    margin: 1%;
    white-space:pre-wrap;
}
code {
    padding: 1%;
    background: rgba(0,0,0,0.05);
    border-radius: 10px 10px 10px 10px;
    box-shadow: 4px 4px 6px rgba(0, 0, 0, .1);
}
input[type=button] {
    padding:0;
    margin:0;
    border:0 none;
    background: rgba(0,0,0,0.01);
}
.countDown {
    display: block;
    padding: 0;
    margin: 0;
}
.timer {
    display:table-row;
}
.timercontrols {
    display:table-row;
}
.step {
    position: relative;
}
.impress-enabled .step {
    margin: 0;
    opacity: 0.3;
    -webkit-transition: opacity 1s;
    -moz-transition:    opacity 1s;
    -ms-transition:     opacity 1s;
    -o-transition:      opacity 1s;
    transition:         opacity 1s;
}
.impress-enabled .step.active { opacity: 1 }
